@@ -1,29 +1,31 @@
-use super::super::{
-    super::{InteractionError, InteractionErrorType},
-    CommandBorrowed,
-};
+use super::super::CommandBorrowed;
 use crate::{
     client::Client,
     error::Error as HttpError,
-    request::{validate_inner, Request, RequestBuilder},
+    request::{Request, RequestBuilder, TryIntoRequest},
     response::ResponseFuture,
     routing::Route,
 };
 use twilight_model::{
     application::command::{Command, CommandOption, CommandType},
-    id::ApplicationId,
+    id::{marker::ApplicationMarker, Id},
+};
+use twilight_validate::command::{
+    chat_input_name as validate_chat_input_name, description as validate_description,
+    options as validate_options, CommandValidationError,
 };
 
 /// Create a new chat input global command.
 ///
 /// The description must be between 1 and 100 characters in length. Creating a
 /// command with the same name as an already-existing global command will
-/// overwrite the old command. See [the discord docs] for more information.
+/// overwrite the old command. See
+/// [Discord Docs/Create Global Application Command].
 ///
-/// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#create-global-application-command
+/// [Discord Docs/Create Global Application Command]: https://discord.com/developers/docs/interactions/application-commands#create-global-application-command
 #[must_use = "requests must be configured and executed"]
 pub struct CreateGlobalChatInputCommand<'a> {
-    application_id: ApplicationId,
+    application_id: Id<ApplicationMarker>,
     default_permission: Option<bool>,
     description: &'a str,
     http: &'a Client,
@@ -34,15 +36,13 @@ pub struct CreateGlobalChatInputCommand<'a> {
 impl<'a> CreateGlobalChatInputCommand<'a> {
     pub(crate) fn new(
         http: &'a Client,
-        application_id: ApplicationId,
+        application_id: Id<ApplicationMarker>,
         name: &'a str,
         description: &'a str,
-    ) -> Result<Self, InteractionError> {
-        if !validate_inner::command_description(&description) {
-            return Err(InteractionError {
-                kind: InteractionErrorType::CommandDescriptionValidationFailed,
-            });
-        }
+    ) -> Result<Self, CommandValidationError> {
+        validate_description(&description)?;
+
+        validate_chat_input_name(name)?;
 
         Ok(Self {
             application_id,
@@ -58,33 +58,18 @@ impl<'a> CreateGlobalChatInputCommand<'a> {
     ///
     /// Required command options must be added before optional options.
     ///
-    /// Errors
+    /// # Errors
     ///
-    /// Returns an [`InteractionErrorType::CommandOptionsRequiredFirst`]
-    /// if a required option was added after an optional option. The problem
-    /// option's index is provided.
-    pub const fn command_options(
+    /// Returns an error of type [`OptionsRequiredFirst`] if a required option
+    /// was added after an optional option. The problem option's index is
+    /// provided.
+    ///
+    /// [`OptionsRequiredFirst`]: twilight_validate::command::CommandValidationErrorType::OptionsRequiredFirst
+    pub fn command_options(
         mut self,
         options: &'a [CommandOption],
-    ) -> Result<Self, InteractionError> {
-        let mut optional_option_added = false;
-        let mut idx = 0;
-
-        while idx < options.len() {
-            let option = &options[idx];
-
-            if !optional_option_added && !option.is_required() {
-                optional_option_added = true
-            }
-
-            if option.is_required() && optional_option_added {
-                return Err(InteractionError {
-                    kind: InteractionErrorType::CommandOptionsRequiredFirst { index: idx },
-                });
-            }
-
-            idx += 1;
-        }
+    ) -> Result<Self, CommandValidationError> {
+        validate_options(options)?;
 
         self.options = Some(options);
 
@@ -98,7 +83,21 @@ impl<'a> CreateGlobalChatInputCommand<'a> {
         self
     }
 
-    fn request(&self) -> Result<Request, HttpError> {
+    /// Execute the request, returning a future resolving to a [`Response`].
+    ///
+    /// [`Response`]: crate::response::Response
+    pub fn exec(self) -> ResponseFuture<Command> {
+        let http = self.http;
+
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for CreateGlobalChatInputCommand<'_> {
+    fn try_into_request(self) -> Result<Request, HttpError> {
         Request::builder(&Route::CreateGlobalCommand {
             application_id: self.application_id.get(),
         })
@@ -112,14 +111,4 @@ impl<'a> CreateGlobalChatInputCommand<'a> {
         })
         .map(RequestBuilder::build)
     }
-
-    /// Execute the request, returning a future resolving to a [`Response`].
-    ///
-    /// [`Response`]: crate::response::Response
-    pub fn exec(self) -> ResponseFuture<Command> {
-        match self.request() {
-            Ok(request) => self.http.request(request),
-            Err(source) => ResponseFuture::error(source),
-        }
-    }
 }
