@@ -1,22 +1,31 @@
-use crate::{client::Client, request::Request, response::ResponseFuture, routing::Route};
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Request, TryIntoRequest},
+    response::ResponseFuture,
+    routing::Route,
+};
 use twilight_model::{
     application::command::Command,
-    id::{ApplicationId, CommandId},
+    id::{
+        marker::{ApplicationMarker, CommandMarker},
+        Id,
+    },
 };
 
 /// Retrieve a global command for an application.
 #[must_use = "requests must be configured and executed"]
 pub struct GetGlobalCommand<'a> {
-    application_id: ApplicationId,
-    command_id: CommandId,
+    application_id: Id<ApplicationMarker>,
+    command_id: Id<CommandMarker>,
     http: &'a Client,
 }
 
 impl<'a> GetGlobalCommand<'a> {
     pub(crate) const fn new(
         http: &'a Client,
-        application_id: ApplicationId,
-        command_id: CommandId,
+        application_id: Id<ApplicationMarker>,
+        command_id: Id<CommandMarker>,
     ) -> Self {
         Self {
             application_id,
@@ -29,11 +38,20 @@ impl<'a> GetGlobalCommand<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Command> {
-        let request = Request::from_route(&Route::GetGlobalCommand {
-            application_id: self.application_id.get(),
-            command_id: self.command_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for GetGlobalCommand<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::GetGlobalCommand {
+            application_id: self.application_id.get(),
+            command_id: self.command_id.get(),
+        }))
     }
 }
