@@ -16,7 +16,6 @@ mod get_channel;
 mod get_pins;
 mod update_channel;
 mod update_channel_permission;
-mod update_channel_permission_configured;
 
 pub use self::{
     create_pin::CreatePin, create_typing_trigger::CreateTypingTrigger,
@@ -24,5 +23,4 @@ pub use self::{
     delete_channel_permission_configured::DeleteChannelPermissionConfigured, delete_pin::DeletePin,
     follow_news_channel::FollowNewsChannel, get_channel::GetChannel, get_pins::GetPins,
     update_channel::UpdateChannel, update_channel_permission::UpdateChannelPermission,
-    update_channel_permission_configured::UpdateChannelPermissionConfigured,
 };
