@@ -1,22 +1,26 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::ListBody, ResponseFuture},
     routing::Route,
 };
-use twilight_model::{id::GuildId, voice::VoiceRegion};
+use twilight_model::{
+    id::{marker::GuildMarker, Id},
+    voice::VoiceRegion,
+};
 
 /// Get voice region data for the guild.
 ///
 /// Can return VIP servers if the guild is VIP-enabled.
 #[must_use = "requests must be configured and executed"]
 pub struct GetGuildVoiceRegions<'a> {
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
 }
 
 impl<'a> GetGuildVoiceRegions<'a> {
-    pub(crate) const fn new(http: &'a Client, guild_id: GuildId) -> Self {
+    pub(crate) const fn new(http: &'a Client, guild_id: Id<GuildMarker>) -> Self {
         Self { guild_id, http }
     }
 
@@ -24,10 +28,19 @@ impl<'a> GetGuildVoiceRegions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<VoiceRegion>> {
-        let request = Request::from_route(&Route::GetGuildVoiceRegions {
-            guild_id: self.guild_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for GetGuildVoiceRegions<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::GetGuildVoiceRegions {
+            guild_id: self.guild_id.get(),
+        }))
     }
 }
