@@ -1,12 +1,16 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::ListBody, ResponseFuture},
     routing::Route,
 };
 use twilight_model::{
     guild::Role,
-    id::{GuildId, RoleId},
+    id::{
+        marker::{GuildMarker, RoleMarker},
+        Id,
+    },
 };
 
 /// Modify the position of the roles.
@@ -14,16 +18,16 @@ use twilight_model::{
 /// The minimum amount of roles to modify, is a swap between two roles.
 #[must_use = "requests must be configured and executed"]
 pub struct UpdateRolePositions<'a> {
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
-    roles: &'a [(RoleId, u64)],
+    roles: &'a [(Id<RoleMarker>, u64)],
 }
 
 impl<'a> UpdateRolePositions<'a> {
     pub(crate) const fn new(
         http: &'a Client,
-        guild_id: GuildId,
-        roles: &'a [(RoleId, u64)],
+        guild_id: Id<GuildMarker>,
+        roles: &'a [(Id<RoleMarker>, u64)],
     ) -> Self {
         Self {
             guild_id,
@@ -36,15 +40,23 @@ impl<'a> UpdateRolePositions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Role>> {
+        let http = self.http;
+
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for UpdateRolePositions<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
         let mut request = Request::builder(&Route::UpdateRolePositions {
             guild_id: self.guild_id.get(),
         });
 
-        request = match request.json(&self.roles) {
-            Ok(request) => request,
-            Err(source) => return ResponseFuture::error(source),
-        };
+        request = request.json(&self.roles)?;
 
-        self.http.request(request.build())
+        Ok(request.build())
     }
 }
