@@ -1,11 +1,10 @@
-pub mod create_guild_from_template;
-pub mod create_template;
-pub mod update_template;
-
+mod create_guild_from_template;
+mod create_template;
 mod delete_template;
 mod get_template;
 mod get_templates;
 mod sync_template;
+mod update_template;
 
 pub use self::{
     create_guild_from_template::CreateGuildFromTemplate, create_template::CreateTemplate,
