@@ -18,7 +18,7 @@
 //! ```no_run
 //! # #[tokio::main]
 //! # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-//! # let user_id = twilight_model::id::UserId::new(1).expect("non zero");
+//! # let user_id = twilight_model::id::Id::new(1);
 //! use std::env;
 //! use twilight_http::Client;
 //!
@@ -71,7 +71,7 @@ use std::{
 };
 use twilight_model::{
     guild::member::{Member, MemberDeserializer, MemberListDeserializer},
-    id::GuildId,
+    id::{marker::GuildMarker, Id},
 };
 
 /// Failure when processing a response body.
@@ -165,7 +165,7 @@ pub enum DeserializeBodyErrorType {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let user_id = twilight_model::id::UserId::new(1).expect("non zero");
+/// # let user_id = twilight_model::id::Id::new(1);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -179,7 +179,7 @@ pub enum DeserializeBodyErrorType {
 /// ```
 #[derive(Debug)]
 pub struct Response<T> {
-    guild_id: Option<GuildId>,
+    guild_id: Option<Id<GuildMarker>>,
     inner: HyperResponse<Body>,
     phantom: PhantomData<T>,
 }
@@ -221,7 +221,7 @@ impl<T> Response<T> {
     /// ```no_run
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    /// # let user_id = twilight_model::id::UserId::new(1).expect("non zero");
+    /// # let user_id = twilight_model::id::Id::new(1);
     /// use std::env;
     /// use twilight_http::Client;
     ///
@@ -308,7 +308,7 @@ impl<T> Response<T> {
     /// Set the ID of the relevant guild.
     ///
     /// Necessary for [`MemberBody`] and [`MemberListBody`] deserialization.
-    pub(crate) fn set_guild_id(&mut self, guild_id: GuildId) {
+    pub(crate) fn set_guild_id(&mut self, guild_id: Id<GuildMarker>) {
         self.guild_id = Some(guild_id);
     }
 
@@ -317,7 +317,7 @@ impl<T> Response<T> {
     /// # Panics
     ///
     /// Panics if the guild ID hasn't been configured.
-    fn guild_id(&self) -> GuildId {
+    fn guild_id(&self) -> Id<GuildMarker> {
         self.guild_id.expect("guild id has not been configured")
     }
 }
@@ -442,7 +442,7 @@ impl Response<MemberListBody> {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let channel_id = twilight_model::id::ChannelId::new(1).expect("non zero");
+/// # let channel_id = twilight_model::id::Id::new(1);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -495,8 +495,8 @@ impl<'a> Iterator for HeaderIter<'a> {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let channel_id = twilight_model::id::ChannelId::new(1).expect("non zero");
-/// # let message_id = twilight_model::id::MessageId::new(2).expect("non zero");
+/// # let channel_id = twilight_model::id::Id::new(1);
+/// # let message_id = twilight_model::id::Id::new(2);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -541,8 +541,8 @@ impl Future for BytesFuture {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let guild_id = twilight_model::id::GuildId::new(1).expect("non zero");
-/// # let emoji_id = twilight_model::id::EmojiId::new(2).expect("non zero");
+/// # let guild_id = twilight_model::id::Id::new(1);
+/// # let emoji_id = twilight_model::id::Id::new(2);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -603,8 +603,8 @@ impl<T: DeserializeOwned + Unpin> Future for ModelFuture<T> {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let guild_id = twilight_model::id::GuildId::new(1).expect("non zero");
-/// # let user_id = twilight_model::id::UserId::new(2).expect("non zero");
+/// # let guild_id = twilight_model::id::Id::new(1);
+/// # let user_id = twilight_model::id::Id::new(2);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -632,11 +632,11 @@ impl<T: DeserializeOwned + Unpin> Future for ModelFuture<T> {
 #[must_use = "futures do nothing unless you `.await` or poll them"]
 pub struct MemberFuture {
     future: BytesFuture,
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
 }
 
 impl MemberFuture {
-    const fn new(bytes: BytesFuture, guild_id: GuildId) -> Self {
+    const fn new(bytes: BytesFuture, guild_id: Id<GuildMarker>) -> Self {
         Self {
             future: bytes,
             guild_id,
@@ -680,7 +680,7 @@ impl Future for MemberFuture {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let guild_id = twilight_model::id::GuildId::new(1).expect("non zero");
+/// # let guild_id = twilight_model::id::Id::new(1);
 /// use std::env;
 /// use twilight_http::Client;
 ///
@@ -711,7 +711,7 @@ impl Future for MemberFuture {
 pub struct MemberListFuture(MemberFuture);
 
 impl MemberListFuture {
-    const fn new(bytes: BytesFuture, guild_id: GuildId) -> Self {
+    const fn new(bytes: BytesFuture, guild_id: Id<GuildMarker>) -> Self {
         Self(MemberFuture {
             future: bytes,
             guild_id,
@@ -759,8 +759,8 @@ impl Future for MemberListFuture {
 /// ```no_run
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-/// # let channel_id = twilight_model::id::ChannelId::new(1).expect("non zero");
-/// # let message_id = twilight_model::id::MessageId::new(2).expect("non zero");
+/// # let channel_id = twilight_model::id::Id::new(1);
+/// # let message_id = twilight_model::id::Id::new(2);
 /// use std::env;
 /// use twilight_http::Client;
 ///
